@@ -70,11 +70,8 @@ static void outfits_sell( unsigned int wid, const char *str );
 static int  outfits_getMod( void );
 static void outfits_rmouse( unsigned int wid, const char *widget_name );
 static void outfits_naevpedia( unsigned int wid, const char *str );
-static const char *outfit_getPrice( const Outfit *outfit, credits_t *price,
-                                    int *canbuy, int *cansell,
-                                    char **player_has );
-static void        outfit_Popdown( unsigned int wid, const char *str );
-static void        outfits_genList( unsigned int wid );
+static void outfit_Popdown( unsigned int wid, const char *str );
+static void outfits_genList( unsigned int wid );
 static void outfits_changeTab( unsigned int wid, const char *wgt, int old,
                                int tab );
 static void outfits_onClose( unsigned int wid, const char *str );
@@ -129,12 +126,13 @@ static void outfit_modifiers( unsigned int wid )
 }
 
 /**
- * Used to force rerenders.
+ * Used to force re-rendering.
  */
 static int outfit_events( unsigned int wid, SDL_Event *evt )
 {
    (void)evt; /* For constness warning. */
-   if ( ( evt->type == SDL_KEYDOWN ) || ( evt->type == SDL_KEYUP ) )
+   if ( ( evt->type == SDL_EVENT_KEY_DOWN ) ||
+        ( evt->type == SDL_EVENT_KEY_UP ) )
       outfit_modifiers( wid );
    return 0;
 }
@@ -153,7 +151,7 @@ static void outfits_onClose( unsigned int wid, const char *str )
 }
 
 /**
- * @brief Opens the outfit exchange center window.
+ * @brief Opens the outfit exchange centre window.
  *
  *    @param wid Window ID to open at.
  *    @param outfits Array (array.h): Outfits to sell. Will be freed.
@@ -202,20 +200,20 @@ void outfits_open( unsigned int wid, const Outfit **outfits, int blackmarket )
    off = -20;
    if ( data->outfits == NULL ) {
       window_addButtonKey( wid, off, 20, bw, bh, "btnCloseOutfits",
-                           _( "Take Off" ), land_buttonTakeoff, SDLK_t );
+                           _( "Take Off" ), land_buttonTakeoff, SDLK_T );
    } else {
       window_addButtonKey( wid, off, 20, bw, bh, "btnCloseOutfits",
-                           _( "Close" ), window_close, SDLK_t );
+                           _( "Close" ), window_close, SDLK_T );
    }
    off -= 20 + bw;
    window_addButtonKey( wid, off, 20, bw, bh, "btnSellOutfit", _( "Sell" ),
-                        outfits_sell, SDLK_s );
+                        outfits_sell, SDLK_S );
    off -= 20 + bw;
    window_addButtonKey( wid, off, 20, bw, bh, "btnBuyOutfit", _( "Buy" ),
-                        outfits_buy, SDLK_b );
+                        outfits_buy, SDLK_B );
    off -= 20 + bw;
    window_addButtonKey( wid, off, 20, bw, bh, "btnNaevpediaOutfits",
-                        _( "Archives" ), outfits_naevpedia, SDLK_a );
+                        _( "Archives" ), outfits_naevpedia, SDLK_A );
 
    /* fancy 256x256 image */
    window_addRect( wid, -40 + 4, -40 + 4, 264, 264, "rctImage", &cBlack, 1 );
@@ -260,8 +258,9 @@ void outfits_regenList( unsigned int wid, const char *str )
    data = window_getData( wid );
 
    /* Must exist. */
-   if ( ( data->outfits == NULL ) &&
-        ( land_getWid( LAND_WINDOW_OUTFITS ) == 0 ) )
+   if ( !land_tabGenerated( LAND_WINDOW_OUTFITS ) ||
+        ( ( data->outfits == NULL ) &&
+          ( land_getWid( LAND_WINDOW_OUTFITS ) == 0 ) ) )
       return;
 
    /* Save focus. */
@@ -292,6 +291,16 @@ static int outfitLand_filter( const Outfit *o )
    Pilot              *p;
    const PlayerShip_t *ps;
 
+   /* Ignore already owned licenses. */
+   if ( outfit_isLicense( o ) &&
+        player_hasLicense( outfit_licenseProvides( o ) ) )
+      return 0;
+
+   /* Ignore already owned maps. */
+   if ( ( outfit_isMap( o ) && map_isUseless( o ) ) ||
+        ( outfit_isLocalMap( o ) && localmap_isUseless( o ) ) )
+      return 0;
+
    switch ( outfit_Mode ) {
    case 0:
       return 1;
@@ -318,11 +327,11 @@ static int outfitLand_filter( const Outfit *o )
       return 0;
 
    case 3:
-      return ( o->slot.size == OUTFIT_SLOT_SIZE_LIGHT );
+      return ( outfit_slotSize( o ) == OUTFIT_SLOT_SIZE_LIGHT );
    case 4:
-      return ( o->slot.size == OUTFIT_SLOT_SIZE_MEDIUM );
+      return ( outfit_slotSize( o ) == OUTFIT_SLOT_SIZE_MEDIUM );
    case 5:
-      return ( o->slot.size == OUTFIT_SLOT_SIZE_HEAVY );
+      return ( outfit_slotSize( o ) == OUTFIT_SLOT_SIZE_HEAVY );
    }
    return 1;
 }
@@ -537,20 +546,22 @@ void outfits_update( unsigned int wid, const char *str )
    outfit = iar_outfits[active][i];
 
    /* new image */
-   window_modifyImage( wid, "imgOutfit", outfit->gfx_store, 256, 256 );
+   window_modifyImage( wid, "imgOutfit", outfit_gfxStore( outfit ), 256, 256 );
 
    /* new text */
-   if ( outfit->slot.type == OUTFIT_SLOT_INTRINSIC ) {
-      scnprintf( buf, sizeof( buf ), "%s\n\n#o%s#0", _( outfit->desc_raw ),
+   if ( outfit_slotType( outfit ) == OUTFIT_SLOT_INTRINSIC ) {
+      scnprintf( buf, sizeof( buf ), "%s\n\n#o%s#0",
+                 _( outfit_descRaw( outfit ) ),
                  _( "This is an intrinsic outfit that will be directly "
                     "equipped on the current ship and can not be moved." ) );
       window_modifyText( wid, "txtDescription", buf );
    } else
-      window_modifyText( wid, "txtDescription", _( outfit->desc_raw ) );
-   buf_price = outfit_getPrice( outfit, &price, &canbuy, &cansell, &youhave );
+      window_modifyText( wid, "txtDescription", _( outfit_descRaw( outfit ) ) );
+   buf_price = outfit_getPrice( outfit, outfits_getMod(), &price, &canbuy,
+                                &cansell, &youhave );
    credits2str( buf_credits, player.p->credits, 2 );
 
-   /* gray out sell button */
+   /* grey out sell button */
    if ( ( outfit_canSell( outfit ) > 0 ) && cansell )
       window_enableButton( wid, "btnSellOutfit" );
    else
@@ -561,11 +572,8 @@ void outfits_update( unsigned int wid, const char *str )
    else
       window_disableButtonSoft( wid, "btnBuyOutfit" );
 
-   mass = outfit->mass;
-   if ( outfit_isLauncher( outfit ) )
-      mass += outfit_amount( outfit ) * outfit->u.lau.ammo_mass;
-   else if ( outfit_isFighterBay( outfit ) )
-      mass += outfit_amount( outfit ) * outfit->u.bay.ship_mass;
+   mass = outfit_mass( outfit ) +
+          outfit_amount( outfit ) * outfit_massAmmo( outfit );
    tonnes2str( buf_mass, (int)round( mass ) );
 
    outfit_getNameWithClass( outfit, buf, sizeof( buf ) );
@@ -579,31 +587,31 @@ void outfits_update( unsigned int wid, const char *str )
    l += scnprintf( &buf[l], sizeof( buf ) - l, "\n%s", buf_price );
    l += scnprintf( &buf[l], sizeof( buf ) - l, "\n%s",
                    ( ( youhave ) != NULL ) ? youhave : buf_credits );
-   if ( outfit->license ) {
-      int meets_reqs = player_hasLicense( outfit->license );
-      k += scnprintf( &lbl[k], sizeof( lbl ) - k, "\n%s", _( "License:" ) );
+
+   if ( outfit_license( outfit ) ) {
+      int meets_reqs = player_hasLicense( outfit_license( outfit ) );
+      k += scnprintf( &lbl[k], sizeof( lbl ) - k, "\n%s", _( "Licence:" ) );
       if ( blackmarket )
          l += scnprintf( &buf[l], sizeof( buf ) - l, "\n%s#0",
                          _( "Not Necessary (Blackmarket)" ) );
       else
-         l += scnprintf( &buf[l], sizeof( buf ) - l, "\n%s%s#0",
-                         meets_reqs ? "" : "#r", _( outfit->license ) );
+         l +=
+            scnprintf( &buf[l], sizeof( buf ) - l, "\n%s%s#0",
+                       meets_reqs ? "" : "#r", _( outfit_license( outfit ) ) );
    }
-   if ( outfit->cond ) {
-      int meets_reqs = 0;
-      if ( land_spob != NULL )
-         meets_reqs = cond_check( outfit->cond );
+   if ( outfit_cond( outfit ) ) {
+      int meets_reqs = cond_check( outfit_cond( outfit ) );
       /*k +=*/scnprintf( &lbl[k], sizeof( lbl ) - k, "\n%s", _( "Requires:" ) );
       if ( blackmarket )
          /*l +=*/scnprintf( &buf[l], sizeof( buf ) - l, "\n%s#0",
                             _( "Not Necessary (Blackmarket)" ) );
       else
          /*l +=*/scnprintf( &buf[l], sizeof( buf ) - l, "\n%s%s#0",
-                            meets_reqs ? "" : "#r", _( outfit->condstr ) );
+                            meets_reqs ? "" : "#r", outfit_condstr( outfit ) );
    }
    window_modifyText( wid, "txtSDesc", lbl );
    window_modifyText( wid, "txtDDesc", buf );
-   summary = pilot_outfitSummary( player.p, outfit, 0 );
+   summary = pilot_outfitSummary( player.p, outfit, 0, NULL );
    window_modifyText( wid, "txtDescShort", summary );
    window_moveWidget( wid, "txtDescShort", 20 + iw + 20, -40 - th );
    window_dimWidget( wid, "txtDescShort", &sw, NULL );
@@ -691,7 +699,7 @@ int outfits_filter( const Outfit **outfits, int                    n,
 
       /* Try to match name somewhere. */
       if ( name != NULL ) {
-         if ( ( SDL_strcasestr( _( o->name ), name ) == NULL ) &&
+         if ( ( SDL_strcasestr( outfit_name( o ), name ) == NULL ) &&
               ( SDL_strcasestr( _( outfit_getType( o ) ), name ) == NULL ) )
             continue;
       }
@@ -718,73 +726,16 @@ static void outfits_naevpedia( unsigned int wid, const char *str )
 /**
  * @brief Returns the price of an outfit (subject to quantity modifier)
  */
-static const char *outfit_getPrice( const Outfit *outfit, credits_t *price,
-                                    int *canbuy, int *cansell,
-                                    char **player_has )
-{
-   static char  pricestr[STRMAX_SHORT];
-   static char  youhave[STRMAX_SHORT];
-   unsigned int q = outfits_getMod();
-   if ( outfit->lua_price == LUA_NOREF ) {
-      price2str( pricestr, outfit->price * q, player.p->credits, 2 );
-      *price   = outfit->price * q;
-      *canbuy  = 1;
-      *cansell = 1;
-      if ( player_has != NULL )
-         *player_has = NULL;
-      return pricestr;
-   }
-   const char *str;
-
-   lua_rawgeti( naevL, LUA_REGISTRYINDEX, outfit->lua_price );
-   lua_pushinteger( naevL, q );
-   if ( nlua_pcall( outfit->lua_env, 1, 4 ) ) { /* */
-      WARN( _( "Outfit '%s' failed to run '%s':\n%s" ), outfit->name, "price",
-            lua_tostring( naevL, -1 ) );
-      *price   = 0;
-      *canbuy  = 0;
-      *cansell = 0;
-      if ( player_has != NULL )
-         *player_has = NULL;
-      lua_pop( naevL, 1 );
-      return pricestr;
-   }
-
-   str = luaL_checkstring( naevL, -4 );
-   strncpy( pricestr, str, sizeof( pricestr ) - 1 );
-   *price   = 0;
-   *canbuy  = lua_toboolean( naevL, -3 );
-   *cansell = lua_toboolean( naevL, -2 );
-   if ( player_has != NULL ) {
-      str = luaL_optstring( naevL, -1, NULL );
-      if ( str == NULL )
-         *player_has = NULL;
-      else {
-         strncpy( youhave, str, sizeof( youhave ) - 1 );
-         *player_has = youhave;
-      }
-   }
-   lua_pop( naevL, 4 );
-
-   return pricestr;
-}
 
 /**
  * @brief Computes the alt text for an outfit.
  */
-int outfit_altText( char *buf, int n, const Outfit *o, const Pilot *plt )
+int outfit_altText( char *buf, int n, const Outfit *o, const Pilot *plt,
+                    PilotOutfitSlot *pos )
 {
    int p = outfit_getNameWithClass( o, buf, n );
-   p += scnprintf( &buf[p], n - p, "\n" );
-   if ( outfit_isProp( o, OUTFIT_PROP_UNIQUE ) )
-      p += scnprintf( &buf[p], n - p, "#o%s#0\n", _( "Unique" ) );
-   if ( o->limit != NULL )
-      p += scnprintf( &buf[p], n - p, "#r%s#0\n",
-                      _( "Only 1 of type per ship" ) );
-   if ( o->slot.spid != 0 )
-      p += scnprintf( &buf[p], n - p, "#o%s#0\n",
-                      _( sp_display( o->slot.spid ) ) );
-   p += scnprintf( &buf[p], n - p, "%s", pilot_outfitSummary( plt, o, 0 ) );
+   p += scnprintf( &buf[p], n - p, "\n%s",
+                   pilot_outfitSummary( plt, o, 0, pos ) );
    return 0;
 }
 
@@ -813,7 +764,7 @@ ImageArrayCell *outfits_imageArrayCells( const Outfit **outfits, int *noutfits,
       }
       if ( needsgfx )
          outfit_gfxStoreLoadNeeded();
-      /* Just to be safe, we assume some ships colud potentially be duplicated.
+      /* Just to be safe, we assume some ships could potentially be duplicated.
        */
 
       /* Set alt text. */
@@ -822,22 +773,22 @@ ImageArrayCell *outfits_imageArrayCells( const Outfit **outfits, int *noutfits,
          glTexture      *t;
          const Outfit   *o = outfits[i];
 
-         coutfits[i].image   = gl_dupTexture( o->gfx_store );
+         coutfits[i].image   = gl_dupTexture( outfit_gfxStore( o ) );
          coutfits[i].caption = strdup( outfit_shortname( o ) );
          if ( !store && outfit_isProp( o, OUTFIT_PROP_UNIQUE ) )
             coutfits[i].quantity = -1; /* Don't display. */
          else
             coutfits[i].quantity = player_outfitOwned( o );
-         coutfits[i].sloticon = sp_icon( o->slot.spid );
+         coutfits[i].sloticon = sp_icon( outfit_slotProperty( o ) );
 
          /* Background colour. */
-         c = outfit_slotSizeColour( &o->slot );
+         c = outfit_slotSizeColour( outfit_slotSize( o ) );
          if ( c == NULL )
             c = &cBlack;
          col_blend( &coutfits[i].bg, c, &cGrey70, 1 );
 
          /* Short description. */
-         coutfits[i].alt = strdup( pilot_outfitSummary( p, o, 1 ) );
+         coutfits[i].alt = strdup( pilot_outfitSummary( p, o, 1, NULL ) );
 
          /* Slot type. */
          if ( ( strcmp( outfit_slotName( o ), "N/A" ) != 0 ) &&
@@ -851,9 +802,10 @@ ImageArrayCell *outfits_imageArrayCells( const Outfit **outfits, int *noutfits,
          }
 
          /* Layers. */
-         coutfits[i].layers = gl_copyTexArray( o->gfx_overlays );
-         if ( o->rarity > 0 ) {
-            t                  = rarity_texture( o->rarity );
+         coutfits[i].layers = gl_copyTexArray( outfit_gfxOverlays( o ) );
+         int rarity         = outfit_rarity( o );
+         if ( rarity > 0 ) {
+            t                  = rarity_texture( rarity );
             coutfits[i].layers = gl_addTexArray( coutfits[i].layers, t );
          }
       }
@@ -945,11 +897,11 @@ int outfit_canBuy( const Outfit *outfit, int wid )
 
    land_errClear();
    failure = 0;
-   outfit_getPrice( outfit, &price, &canbuy, &cansell, NULL );
+   outfit_getPrice( outfit, outfits_getMod(), &price, &canbuy, &cansell, NULL );
 
    /* Special exception for local map. */
+   int sold = 0;
    if ( outfit != omap ) {
-      int sold = 0;
       /* See if the player previously sold it. */
       for ( int i = 0; i < array_size( outfits_sold ); i++ ) {
          if ( outfits_sold[i].o == outfit ) {
@@ -973,8 +925,8 @@ int outfit_canBuy( const Outfit *outfit, int wid )
    }
 
    /* Intrinsic. */
-   if ( outfit->slot.type == OUTFIT_SLOT_INTRINSIC ) {
-      if ( pilot_hasOutfitLimit( player.p, outfit->limit ) ) {
+   if ( outfit_slotType( outfit ) == OUTFIT_SLOT_INTRINSIC ) {
+      if ( pilot_hasOutfitLimit( player.p, outfit_limit( outfit ) ) ) {
          land_errDialogueBuild(
             _( "You can only equip one of this outfit type." ) );
          return 0;
@@ -989,14 +941,14 @@ int outfit_canBuy( const Outfit *outfit, int wid )
       return 0;
    }
    /* GUI already owned */
-   if ( outfit_isGUI( outfit ) && player_guiCheck( outfit->u.gui.gui ) ) {
+   if ( outfit_isGUI( outfit ) && player_guiCheck( outfit_gui( outfit ) ) ) {
       land_errDialogueBuild( _( "You already own this GUI." ) );
       return 0;
    }
-   /* Already has license. */
+   /* Already has licence. */
    if ( outfit_isLicense( outfit ) &&
-        player_hasLicense( outfit->u.lic.provides ) ) {
-      land_errDialogueBuild( _( "You already have this license." ) );
+        player_hasLicense( outfit_licenseProvides( outfit ) ) ) {
+      land_errDialogueBuild( _( "You already have this licence." ) );
       return 0;
    }
    /* Not enough $$ */
@@ -1006,17 +958,18 @@ int outfit_canBuy( const Outfit *outfit, int wid )
       land_errDialogueBuild( _( "You need %s more." ), buf );
       failure = 1;
    }
-   /* Needs license. */
-   if ( !blackmarket && !player_hasLicense( outfit->license ) ) {
+   /* Needs licence. */
+   if ( !sold && !blackmarket &&
+        !player_hasLicense( outfit_license( outfit ) ) ) {
       land_errDialogueBuild(
-         _( "You need the '%s' license to buy this outfit." ),
-         _( outfit->license ) );
+         _( "You need the '%s' licence to buy this outfit." ),
+         _( outfit_license( outfit ) ) );
       failure = 1;
    }
    /* Needs requirements. */
-   if ( !blackmarket && ( outfit->cond != NULL ) &&
-        !cond_check( outfit->cond ) ) {
-      land_errDialogueBuild( "%s", _( outfit->condstr ) );
+   if ( !sold && !blackmarket && ( outfit_cond( outfit ) != NULL ) &&
+        !cond_check( outfit_cond( outfit ) ) ) {
+      land_errDialogueBuild( "%s", outfit_condstr( outfit ) );
       failure = 1;
    }
    /* Custom condition failed. */
@@ -1062,7 +1015,7 @@ static void outfits_buy( unsigned int wid, const char *str )
    q      = outfits_getMod();
    /* Can only get one unique item. */
    if ( outfit_isProp( outfit, OUTFIT_PROP_UNIQUE ) ||
-        ( outfit->slot.type == OUTFIT_SLOT_INTRINSIC ) ||
+        ( outfit_slotType( outfit ) == OUTFIT_SLOT_INTRINSIC ) ||
         outfit_isMap( outfit ) || outfit_isLocalMap( outfit ) ||
         outfit_isGUI( outfit ) || outfit_isLicense( outfit ) )
       q = MIN( q, 1 );
@@ -1083,21 +1036,21 @@ static void outfits_buy( unsigned int wid, const char *str )
    }
 
    /* Give dialogue when trying to buy intrinsic. */
-   if ( outfit->slot.type == OUTFIT_SLOT_INTRINSIC )
+   if ( outfit_slotType( outfit ) == OUTFIT_SLOT_INTRINSIC )
       if ( !dialogue_YesNo(
               _( "Buy Intrinsic Outfit?" ),
               _( "Are you sure you wish to buy '%s'? It will be automatically "
                  "equipped on your current ship '%s'." ),
-              _( outfit->name ), player.p->name ) )
+              outfit_name( outfit ), player.p->name ) )
          return;
 
    /* Try Lua. */
-   if ( outfit->lua_buy != LUA_NOREF ) {
-      lua_rawgeti( naevL, LUA_REGISTRYINDEX, outfit->lua_buy );
+   if ( outfit_luaBuy( outfit ) != LUA_NOREF ) {
+      lua_rawgeti( naevL, LUA_REGISTRYINDEX, outfit_luaBuy( outfit ) );
       lua_pushinteger( naevL, q );
-      if ( nlua_pcall( outfit->lua_env, 1, 2 ) ) { /* */
-         WARN( _( "Outfit '%s' failed to run '%s':\n%s" ), outfit->name,
-               "price", lua_tostring( naevL, -1 ) );
+      if ( nlua_pcall( outfit_luaEnv( outfit ), 1, 2 ) ) { /* */
+         WARN( _( "Outfit '%s' failed to run '%s':\n%s" ),
+               outfit_name( outfit ), "price", lua_tostring( naevL, -1 ) );
          lua_pop( naevL, 1 );
       }
 
@@ -1113,7 +1066,8 @@ static void outfits_buy( unsigned int wid, const char *str )
 
       lua_pop( naevL, 2 );
    } else
-      player_modCredits( -outfit->price * player_addOutfit( outfit, q ) );
+      player_modCredits( -outfit_price( outfit ) *
+                         player_addOutfit( outfit, q ) );
 
    /* Actually buy the outfit. */
    outfits_updateEquipmentOutfits();
@@ -1143,7 +1097,7 @@ int outfit_canSell( const Outfit *outfit )
    credits_t price;
 
    land_errClear();
-   outfit_getPrice( outfit, &price, &canbuy, &cansell, NULL );
+   outfit_getPrice( outfit, outfits_getMod(), &price, &canbuy, &cansell, NULL );
 
    /* Unique item. */
    if ( outfit_isProp( outfit, OUTFIT_PROP_UNIQUE ) ) {
@@ -1160,9 +1114,9 @@ int outfit_canSell( const Outfit *outfit )
       land_errDialogueBuild( _( "You can't sell a GUI." ) );
       failure = 1;
    }
-   /* License check. */
+   /* Licence check. */
    if ( outfit_isLicense( outfit ) ) {
-      land_errDialogueBuild( _( "You can't sell a license." ) );
+      land_errDialogueBuild( _( "You can't sell a licence." ) );
       failure = 1;
    }
    /* has no outfits to sell */
@@ -1208,28 +1162,29 @@ static void outfits_sell( unsigned int wid, const char *str )
    }
 
    /* Try Lua. */
-   if ( outfit->lua_sell != LUA_NOREF ) {
-      lua_rawgeti( naevL, LUA_REGISTRYINDEX, outfit->lua_sell );
+   if ( outfit_luaSell( outfit ) != LUA_NOREF ) {
+      lua_rawgeti( naevL, LUA_REGISTRYINDEX, outfit_luaSell( outfit ) );
       lua_pushinteger( naevL, q );
-      if ( nlua_pcall( outfit->lua_env, 1, 2 ) ) { /* */
-         WARN( _( "Outfit '%s' failed to run '%s':\n%s" ), outfit->name,
-               "price", lua_tostring( naevL, -1 ) );
+      if ( nlua_pcall( outfit_luaEnv( outfit ), 1, 2 ) ) { /* */
+         WARN( _( "Outfit '%s' failed to run '%s':\n%s" ),
+               outfit_name( outfit ), "price", lua_tostring( naevL, -1 ) );
          lua_pop( naevL, 1 );
       }
 
-      int bought = lua_toboolean( naevL, -2 );
+      int sold = lua_toboolean( naevL, -2 );
 
-      if ( !bought ) {
+      if ( !sold ) {
          dialogue_alert( "%s", lua_tostring( naevL, -1 ) );
          lua_pop( naevL, 2 );
          return;
       }
       q = luaL_checkinteger( naevL, -1 );
+      q = player_rmOutfit( outfit, q );
 
       lua_pop( naevL, 2 );
    } else {
       q = player_rmOutfit( outfit, q );
-      player_modCredits( outfit->price * q );
+      player_modCredits( outfit_price( outfit ) * q );
    }
 
    outfits_updateEquipmentOutfits();
@@ -1274,9 +1229,9 @@ static int outfits_getMod( void )
 {
    SDL_Keymod mods = SDL_GetModState();
    int        q    = 1;
-   if ( mods & ( KMOD_LCTRL | KMOD_RCTRL ) )
+   if ( mods & ( SDL_KMOD_LCTRL | SDL_KMOD_RCTRL ) )
       q *= 5;
-   if ( mods & ( KMOD_LSHIFT | KMOD_RSHIFT ) )
+   if ( mods & ( SDL_KMOD_LSHIFT | SDL_KMOD_RSHIFT ) )
       q *= 10;
    return q;
 }
