@@ -249,7 +249,7 @@ static int map_sortCompare( const void *p1, const void *p2 )
       return -1;
 
    /* If they're the same it doesn't matter, so we'll sort by name. */
-   return strcasecmp( f1->sys->name, f2->sys->name );
+   return SDL_strcasecmp( f1->sys->name, f2->sys->name );
 }
 
 /**
@@ -361,7 +361,7 @@ static void map_findAccumulateResult( map_find_t *found, int n, StarSystem *sys,
 }
 
 /**
- * @brief Centers the search result in the map, opening if necessary.
+ * @brief Centres the search result in the map, opening if necessary.
  */
 static void map_findSelect( const StarSystem *sys )
 {
@@ -538,18 +538,17 @@ static char **map_fuzzyOutfits( Outfit **o, const char *name )
 
    /* Do fuzzy search. */
    for ( int i = 0; i < array_size( o ); i++ ) {
-      if ( SDL_strcasestr( _( o[i]->name ), name ) != NULL )
-         array_push_back( &names, o[i]->name );
-      else if ( ( o[i]->typename != NULL ) &&
-                SDL_strcasestr( o[i]->typename, name ) != NULL )
-         array_push_back( &names, o[i]->name );
-      else if ( ( o[i]->condstr != NULL ) &&
-                SDL_strcasestr( o[i]->condstr, name ) != NULL )
-         array_push_back( &names, o[i]->name );
+      if ( SDL_strcasestr( outfit_name( o[i] ), name ) != NULL )
+         array_push_back( &names, (char *)outfit_rawname( o[i] ) );
+      else if ( SDL_strcasestr( outfit_getType( o[i] ), name ) != NULL )
+         array_push_back( &names, (char *)outfit_rawname( o[i] ) );
+      else if ( ( outfit_condstr( o[i] ) != NULL ) &&
+                SDL_strcasestr( outfit_condstr( o[i] ), name ) != NULL )
+         array_push_back( &names, (char *)outfit_rawname( o[i] ) );
       else if ( SDL_strcasestr( outfit_description( o[i] ), name ) != NULL )
-         array_push_back( &names, o[i]->name );
+         array_push_back( &names, (char *)outfit_rawname( o[i] ) );
       else if ( SDL_strcasestr( outfit_summary( o[i], 0 ), name ) != NULL )
-         array_push_back( &names, o[i]->name );
+         array_push_back( &names, (char *)outfit_rawname( o[i] ) );
    }
 
    return names;
@@ -573,7 +572,7 @@ static char **map_outfitsMatch( const char *name )
 }
 /**
  * @brief Add widgets to the extended area on the outfit search
- *    listpanel.
+ *    list panel.
  *
  *    @param wid_results The ID of the Search Results window we're populating
  *    @param x The x offset where we can start drawing
@@ -602,7 +601,7 @@ static void map_addOutfitDetailFields( unsigned int wid_results, int x, int y,
    l += scnprintf( &buf[l], sizeof( buf ) - l, "#n%s#0\n", _( "Mass:" ) );
    l += scnprintf( &buf[l], sizeof( buf ) - l, "#n%s#0\n", _( "Price:" ) );
    l += scnprintf( &buf[l], sizeof( buf ) - l, "#n%s#0\n", _( "Money:" ) );
-   l += scnprintf( &buf[l], sizeof( buf ) - l, "#n%s#0\n", _( "License:" ) );
+   l += scnprintf( &buf[l], sizeof( buf ) - l, "#n%s#0\n", _( "Licence:" ) );
    window_addText( wid_results, iw + 20, -50 - 128 - 10, 90, 160, 0, "txtSDesc",
                    &gl_smallFont, NULL, buf );
    window_addText( wid_results, iw + 20, -50 - 128 - 10,
@@ -613,9 +612,9 @@ static void map_addOutfitDetailFields( unsigned int wid_results, int x, int y,
 }
 
 /**
- * @brief Update the listPanel outfit details to the outfit selected.
+ * @brief Update the `listPanel` outfit details to the outfit selected.
  *
- *    @param wid The windowid of the window we're updating.
+ *    @param wid The window id of the window we are updating.
  *    @param wgtname The name of the list that was selected.
  *    @param x The x offset where we can start drawing
  *    @param y the y offset where we can start drawing
@@ -635,28 +634,25 @@ static void map_showOutfitDetail( unsigned int wid, const char *wgtname, int x,
    size_t l = 0;
    double th;
    int    iw;
-   double mass = outfit->mass;
+   double mass = outfit_mass( outfit );
 
    /* 452 px is the sum of the 128 px outfit image width, its 4 px border,
     * a 20 px gap, 280 px for the outfit's name and a final 20 px gap. */
    iw = w - 452;
 
-   outfit_gfxStoreLoad( (Outfit *)outfit );
-   window_modifyImage( wid, "imgOutfit", outfit->gfx_store, 128, 128 );
+   window_modifyImage( wid, "imgOutfit", outfit_gfxStore( outfit ), 128, 128 );
    l = outfit_getNameWithClass( outfit, buf, sizeof( buf ) );
    l += scnprintf( &buf[l], sizeof( buf ) - l, " %s",
-                   pilot_outfitSummary( player.p, outfit, 0 ) );
+                   pilot_outfitSummary( player.p, outfit, 0, NULL ) );
    window_modifyText( wid, "txtDescShort", buf );
    th = gl_printHeightRaw( &gl_smallFont, 280, buf );
 
-   if ( outfit_isLauncher( outfit ) )
-      mass += outfit_amount( outfit ) * outfit->u.lau.ammo_mass;
-   else if ( outfit_isFighterBay( outfit ) )
-      mass += outfit_amount( outfit ) * outfit->u.bay.ship_mass;
+   /* Launchers and fighter bays have non-zero ammo mass. */
+   mass += outfit_amount( outfit ) * outfit_ammoMass( outfit );
 
    window_modifyText( wid, "txtDescription",
-                      pilot_outfitDescription( player.p, outfit ) );
-   credits2str( buf_price, outfit->price, 2 );
+                      pilot_outfitDescription( player.p, outfit, NULL ) );
+   credits2str( buf_price, outfit_price( outfit ), 2 );
    credits2str( buf_money, player.p->credits, 2 );
    tonnes2str( buf_mass, (int)round( mass ) );
 
@@ -667,8 +663,9 @@ static void map_showOutfitDetail( unsigned int wid, const char *wgtname, int x,
    l += scnprintf( &buf[l], sizeof( buf ) - l, "%s\n", buf_price );
    l += scnprintf( &buf[l], sizeof( buf ) - l, "%s\n", buf_money );
    l += scnprintf( &buf[l], sizeof( buf ) - l, "%s\n",
-                   ( outfit->license != NULL ) ? _( outfit->license )
-                                               : _( "None" ) );
+                   ( outfit_license( outfit ) != NULL )
+                      ? _( outfit_license( outfit ) )
+                      : _( "None" ) );
 
    window_modifyText( wid, "txtDDesc", buf );
    window_resizeWidget( wid, "txtDescShort", 280, th );
@@ -681,9 +678,9 @@ static void map_showOutfitDetail( unsigned int wid, const char *wgtname, int x,
 }
 
 /**
- * @brief Adjust "Show all"/"Find" button label.
+ * @brief Adjust "Show all" / "Find" button label.
  *
- *    @param wid_map_find The windowid of the find window.
+ *    @param wid_map_find The window id of the find window.
  *    @param name         The widget name of the input widget.
  */
 static void map_adjustButtonLabel( unsigned int wid_map_find, const char *name )
