@@ -58,14 +58,6 @@ static int factionL_tags( lua_State *L );
 static int factionL_dynAdd( lua_State *L );
 static int factionL_dynAlly( lua_State *L );
 static int factionL_dynEnemy( lua_State *L );
-/* Following functions are deprecated and should be removed in 0.13.0. */
-static int factionL_modplayer( lua_State *L );
-static int factionL_modplayersingle( lua_State *L );
-static int factionL_modplayerraw( lua_State *L );
-static int factionL_setplayerstanding( lua_State *L );
-static int factionL_playerstanding( lua_State *L );
-static int factionL_playerstandingdefault( lua_State *L );
-/* End of deprecated functions. */
 
 static const luaL_Reg faction_methods[] = {
    { "exists", factionL_exists },
@@ -87,12 +79,6 @@ static const luaL_Reg faction_methods[] = {
    { "reputationDefault", factionL_reputationDefault },
    { "setReputationGlobal", factionL_setReputationGlobal },
    { "applyLocalThreshold", factionL_applyLocalThreshold },
-   { "modPlayer", factionL_modplayer },
-   { "modPlayerSingle", factionL_modplayersingle },
-   { "modPlayerRaw", factionL_modplayerraw },
-   { "setPlayerStanding", factionL_setplayerstanding },
-   { "playerStanding", factionL_playerstanding },
-   { "playerStandingDefault", factionL_playerstandingdefault },
    { "enemies", factionL_enemies },
    { "allies", factionL_allies },
    { "usesHiddenJumps", factionL_usesHiddenJumps },
@@ -116,7 +102,7 @@ static const luaL_Reg faction_methods[] = {
  *    @param env Environment to load faction library into.
  *    @return 0 on success.
  */
-int nlua_loadFaction( nlua_env env )
+int nlua_loadFaction( nlua_env *env )
 {
    nlua_register( env, FACTION_METATABLE, faction_methods, 1 );
    return 0; /* No error */
@@ -129,7 +115,7 @@ int nlua_loadFaction( nlua_env env )
  * @code
  * f = faction.get( "Empire" )
  * if f:playerStanding() < 0 then
- *    -- player is hostile to "Empire"
+ *    -- player is hostile to Empire
  * end
  * @endcode
  *
@@ -288,9 +274,9 @@ int lua_isfaction( lua_State *L, int ind )
 }
 
 /**
- * @brief __eq (equality) metamethod for factions.
+ * @brief equality (`__eq()`) metamethod for factions.
  *
- * You can use the '==' operator within Lua to compare factions with this.
+ * You can use the `==` operator within Lua to compare factions with this.
  *
  * @usage if f == faction.get( "Dvaered" ) then
  *
@@ -375,7 +361,7 @@ static int factionL_longname( lua_State *L )
  *
  *    @luatparam Faction f Faction to check against.
  *    @luatparam Faction n Faction to check if is true neutral.
- *    @luatreturn boolean true if they are truely neutral, false if they aren't.
+ *    @luatreturn boolean true if they are truly neutral, false if they aren't.
  * @luafunc areNeutral
  */
 static int factionL_areneutral( lua_State *L )
@@ -447,8 +433,8 @@ static int factionL_areallies( lua_State *L )
  *    @luatparam System|nil Whether to make the faction hit local at a system,
  * or global affecting all systems of the faction.
  *    @luatparam[opt="script"] string reason Reason behind it. This is passed as
- * a string to the faction "hit" function. The engine can generate "kill" and
- * "distress" sources. For missions the default is "script".
+ * a string to the faction `hit` function. The engine can generate `destroy` and
+ * `distress` sources. For missions the default is `script`.
  *    @luatparam[opt=false] boolean single Whether or not the hit should affect
  * allies/enemies of the faction getting a hit.
  *    @luatreturn How much the reputation was actually changed after Lua script
@@ -476,11 +462,11 @@ static int factionL_hit( lua_State *L )
  *    @luatparam System|nil Whether to make the faction hit local at a system,
  * or global.
  *    @luatparam[opt="script"] string reason Reason behind it. This is passed as
- * a string to the faction "hit" function. The engine can generate "kill" and
- * "distress" sources. For missions the default is "script".
+ * a string to the faction `hit` function. The engine can generate `destroy` and
+ * `distress` sources. For missions the default is `script`.
  *    @luatreturn How much the reputation was actually changed after Lua script
  * was run.
- * @luafunc hit
+ * @luafunc hitTest
  */
 static int factionL_hitTest( lua_State *L )
 {
@@ -511,7 +497,7 @@ static int factionL_reputationGlobal( lua_State *L )
 }
 
 /**
- * @brief Gets the human readable standing text correpsonding (translated).
+ * @brief Gets the human readable standing text corresponding (translated).
  *
  *    @luatparam faction f Faction to get standing text from.
  *    @luatparam[opt=f:reputationGlobal()] number|nil val Value to get the
@@ -547,7 +533,7 @@ static int factionL_reputationDefault( lua_State *L )
 
 /**
  * @brief Overrides the player's faction global standing with a faction. Use
- * sparingly as it overrites local standings at all systems.
+ * sparingly as it overwrites local standings at all systems.
  *
  *    @luatparam Faction f Faction to set the player's global reputation with.
  *    @luatparam number The value of the reputation to set to.
@@ -567,8 +553,8 @@ static int factionL_setReputationGlobal( lua_State *L )
  * system. Meant to be used when computing faction hits from the faction
  * standing Lua scripts. Not meant for use elsewhere.
  *
- *    @luatparam Faction f Faction to apply local thresholding to.
- *    @luatparam System sys System to compute the thresholding from. This will
+ *    @luatparam Faction f Faction to apply local threshold to.
+ *    @luatparam System sys System to compute the threshold from. This will
  * be the reference and will not have its value modified.
  * @luafunc applyLocalThreshold
  */
@@ -580,138 +566,6 @@ static int factionL_applyLocalThreshold( lua_State *L )
    return 0;
 }
 
-/**
- * @brief Modifies the player's standing with the faction.
- *
- * Also modifies standing with allies and enemies of the faction.
- *
- * @usage f:modPlayer( -5 ) -- Lowers faction by 5
- *
- *    @luatparam Faction f Faction to modify player's standing with.
- *    @luatparam number mod The modifier to modify faction by.
- *    @luatparam[opt="script"] string reason Reason behind it. This is passed as
- * a string to the faction "hit" function. The engine can generate "kill" and
- * "distress" sources. For missions the default is "script".
- * @luafunc modPlayer
- */
-static int factionL_modplayer( lua_State *L )
-{
-   NLUA_DEPRECATED( L, "modPlayer" );
-   int         f      = luaL_validfaction( L, 1 );
-   double      n      = luaL_checknumber( L, 2 );
-   const char *reason = luaL_optstring( L, 3, "script" );
-   faction_modPlayer( f, n, reason );
-   return 0;
-}
-
-/**
- * @brief Modifies the player's standing with the faction.
- *
- * Does not affect other faction standings.
- *
- * @usage f:modPlayerSingle( 10 )
- *
- *    @luatparam Faction f Faction to modify player's standing with.
- *    @luatparam number mod The modifier to modify faction by.
- *    @luatparam[opt="script"] string reason Reason behind it. This is passed as
- * a string to the faction "hit" function. The engine can generate "kill" and
- * "distress" sources. For missions the default is "script".
- * @luafunc modPlayerSingle
- */
-static int factionL_modplayersingle( lua_State *L )
-{
-   NLUA_DEPRECATED( L, "modPlayerSingle" );
-   int         f      = luaL_validfaction( L, 1 );
-   double      n      = luaL_checknumber( L, 2 );
-   const char *reason = luaL_optstring( L, 3, "script" );
-   faction_modPlayerSingle( f, n, reason );
-   return 0;
-}
-
-/**
- * @brief Modifies the player's standing with the faction.
- *
- * Does not affect other faction standings and is not processed by the faction
- *  Lua script, so it indicates exactly the amount to be changed.
- *
- * @usage f:modPlayerRaw( 10 )
- *
- *    @luatparam Faction f Faction to modify player's standing with.
- *    @luatparam number mod The modifier to modify faction by.
- * @luafunc modPlayerRaw
- */
-static int factionL_modplayerraw( lua_State *L )
-{
-   NLUA_DEPRECATED( L, "modPlayerRaw" );
-   int    f = luaL_validfaction( L, 1 );
-   double n = luaL_checknumber( L, 2 );
-   faction_modPlayerRaw( f, n );
-   return 0;
-}
-
-/**
- * @brief Sets the player's standing with the faction.
- *
- * @usage f:setPlayerStanding(70) -- Make player an ally
- *
- *    @luatparam Faction f Faction to set the player's standing for.
- *    @luatparam number value Value to set the player's standing to (from -100
- * to 100).
- * @luafunc setPlayerStanding
- */
-static int factionL_setplayerstanding( lua_State *L )
-{
-   NLUA_DEPRECATED( L, "setPlayerStanding" );
-   int    f = luaL_validfaction( L, 1 );
-   double n = luaL_checknumber( L, 2 );
-   faction_setReputation( f, n );
-   return 0;
-}
-
-/**
- * @brief Gets the player's standing with the faction.
- *
- * @usage if f:playerStanding() > 70 then -- Player is an ally
- * @usage _v, str = f:playerStanding(50) -- Get the standing text for a value of
- * 50
- *
- *    @luatparam Faction f Faction to get player's standing with.
- *    @luatparam number value Faction standing value to get string of.
- *    @luatreturn number The value of the standing and the human readable
- * string.
- *    @luatreturn string The text corresponding to the standing (translated).
- * @luafunc playerStanding
- */
-static int factionL_playerstanding( lua_State *L )
-{
-   NLUA_DEPRECATED( L, "playerStanding" );
-   int    f = luaL_validfaction( L, 1 );
-   double n;
-   if ( !lua_isnoneornil( L, 2 ) )
-      n = luaL_checknumber( L, 2 );
-   else
-      n = faction_reputation( f );
-   lua_pushnumber( L, n );
-   lua_pushstring( L, faction_getStandingTextAtValue( f, n ) );
-   return 2;
-}
-
-/**
- * @brief Gets the player's default standing with the faction.
- *
- *    @luatparam Faction f Faction to get player's default standing with.
- *    @luatreturn number The value of the standing.
- * @luafunc playerStandingDefault
- */
-static int factionL_playerstandingdefault( lua_State *L )
-{
-   NLUA_DEPRECATED( L, "playerStandingDefault" );
-   int    f = luaL_validfaction( L, 1 );
-   double n = faction_reputationDefault( f );
-   lua_pushnumber( L, n );
-   return 1;
-}
-
 /**
  * @brief Gets the enemies of the faction.
  *
@@ -877,12 +731,12 @@ static int factionL_isStatic( lua_State *L )
 }
 
 /**
- * @brief Gets the overriden reputation value of a faction.
+ * @brief Gets the overridden reputation value of a faction.
  *
  *    @luatparam Faction f Faction to get whether or not the reputation is
- * overriden and the value.
+ * overridden and the value.
  *    @luatreturn number|nil The override reputation value or nil if not
- * overriden.
+ * overridden.
  * @luafunc reputationOverride
  */
 static int factionL_reputationOverride( lua_State *L )
@@ -897,7 +751,7 @@ static int factionL_reputationOverride( lua_State *L )
 }
 
 /**
- * @brief Gets the overriden reputation value of a faction.
+ * @brief Gets the overridden reputation value of a faction.
  *
  *    @luatparam Faction f Faction to enable/disable reputation override of.
  *    @luatparam number|nil Sets the faction reputation override to the value if
@@ -941,10 +795,10 @@ static int factionL_tags( lua_State *L )
  * faction.
  *    @luatparam string name Name to give the faction.
  *    @luatparam[opt] string display Display name to give the faction.
- *    @luatparam[opt] table params Table of parameters. Options include "ai"
- * (string) to set the AI to use, "clear_allies" (boolean) to clear all allies,
- * "clear_enemies" (boolean) to clear all enemies, "player" (number) to set the
- * default player standing, "colour" (string|colour) which represents the
+ *    @luatparam[opt] table params Table of parameters. Options include `ai`
+ * (string) to set the AI to use, `clear_allies` (boolean) to clear all allies,
+ * `clear_enemies` (boolean) to clear all enemies, `player` (number) to set the
+ * default player standing, `colour` (string|colour) which represents the
  * factional colours.
  * @luafunc dynAdd
  */
