@@ -42,7 +42,8 @@ static int gfxL_renderCircleH( lua_State *L );
 static int gfxL_renderLinesH( lua_State *L );
 static int gfxL_clearDepth( lua_State *L );
 static int gfxL_fontSize( lua_State *L );
-/* TODO get rid of printDim and print in favour of printfDim and printf */
+/* TODO get rid of `printDim` and `print` in favour of `printfDim` and `printf`
+ */
 static int gfxL_printfDim( lua_State *L );
 static int gfxL_printfEnd( lua_State *L );
 static int gfxL_printfWrap( lua_State *L );
@@ -109,14 +110,13 @@ static const luaL_Reg gfxL_methods[] = {
  *    @param env Environment to load graphics library into.
  *    @return 0 on success.
  */
-int nlua_loadGFX( nlua_env env )
+int nlua_loadGFX( nlua_env *env )
 {
    /* Register the values */
    nlua_register( env, "gfx", gfxL_methods, 0 );
 
    /* We also load the texture, colour, font, and transform modules as
     * dependencies. */
-   nlua_loadCol( env );
    nlua_loadTex( env );
    nlua_loadFont( env );
    nlua_loadTransform( env );
@@ -167,8 +167,7 @@ static int gfxL_dim( lua_State *L )
 /**
  * @brief Gets the screen coordinates from game coordinates.
  *
- *    @luatparam Vec2 Vector of coordinates to transnform.
- *    @luatparam[opt=false] boolean Whether or not to invert y axis.
+ *    @luatparam Vec2 Vector of coordinates to transform.
  *    @luatreturn Vec2 Transformed vector.
  * @luafunc screencoords
  */
@@ -176,11 +175,10 @@ static int gfxL_screencoords( lua_State *L )
 {
    vec2        screen;
    double      x, y;
-   const vec2 *game   = luaL_checkvector( L, 1 );
-   int         invert = lua_toboolean( L, 2 );
+   const vec2 *game = luaL_checkvector( L, 1 );
    gl_gameToScreenCoords( &x, &y, game->x, game->y );
-   if ( invert )
-      y = SCREEN_H - y;
+   // Lua uses entirely Love2D coordinates
+   y = SCREEN_H - y;
    vec2_cset( &screen, x, y );
    lua_pushvector( L, screen );
    return 1;
@@ -230,16 +228,16 @@ static int gfxL_renderTex( lua_State *L )
 
    /* Some safety checking. */
 #if DEBUGGING
-   if ( sx < 0 || sx >= tex->sx )
+   if ( sx < 0 || sx >= tex_sx( tex ) )
       return NLUA_ERROR( L,
                          _( "Texture '%s' trying to render out of bounds (X "
                             "position) sprite: %d > %d." ),
-                         tex->name, sx + 1, tex->sx );
-   if ( sy < 0 || sy >= tex->sy )
+                         tex_name( tex ), sx + 1, tex_sx( tex ) );
+   if ( sy < 0 || sy >= tex_sy( tex ) )
       return NLUA_ERROR( L,
                          _( "Texture '%s' trying to render out of bounds (Y "
                             "position) sprite: %d > %d." ),
-                         tex->name, sy + 1, tex->sy );
+                         tex_name( tex ), sy + 1, tex_sy( tex ) );
 #endif /* DEBUGGING */
 
    /* Render. */
@@ -290,16 +288,16 @@ static int gfxL_renderTexScale( lua_State *L )
 
    /* Some safety checking. */
 #if DEBUGGING
-   if ( sx >= tex->sx )
+   if ( sx >= tex_sx( tex ) )
       return NLUA_ERROR( L,
                          _( "Texture '%s' trying to render out of bounds (X "
                             "position) sprite: %d > %d." ),
-                         tex->name, sx + 1, tex->sx );
-   if ( sx >= tex->sx )
+                         tex_name( tex ), sx + 1, tex_sx( tex ) );
+   if ( sx >= tex_sx( tex ) )
       return NLUA_ERROR( L,
                          _( "Texture '%s' trying to render out of bounds (Y "
                             "position) sprite: %d > %d." ),
-                         tex->name, sy + 1, tex->sy );
+                         tex_name( tex ), sy + 1, tex_sy( tex ) );
 #endif /* DEBUGGING */
 
    /* Render. */
@@ -311,7 +309,7 @@ static int gfxL_renderTexScale( lua_State *L )
 /**
  * @brief Renders a texture using the core render function.
  *
- * This function is far more complex than renderTex, however it allows much
+ * This function is far more complex than `renderTex`, however it allows much
  *  more fine grained control over the entire render process and puts you
  *  closer to the actual OpenGL calls.
  *
@@ -360,25 +358,26 @@ static int gfxL_renderTexRaw( lua_State *L )
 
    /* Some safety checking. */
 #if DEBUGGING
-   if ( sx >= t->sx )
+   if ( sx >= tex_sx( t ) )
       return NLUA_ERROR( L,
                          _( "Texture '%s' trying to render out of bounds (X "
                             "position) sprite: %d > %d." ),
-                         t->name, sx + 1, t->sx );
-   if ( sx >= t->sx )
+                         tex_name( t ), sx + 1, tex_sx( t ) );
+   if ( sx >= tex_sx( t ) )
       return NLUA_ERROR( L,
                          _( "Texture '%s' trying to render out of bounds (Y "
                             "position) sprite: %d > %d." ),
-                         t->name, sy + 1, t->sy );
+                         tex_name( t ), sy + 1, tex_sy( t ) );
 #endif /* DEBUGGING */
 
    /* Translate as needed. */
-   tx = ( tx * t->sw + t->sw * (double)( sx ) ) / t->w;
-   tw = tw * t->srw;
+   tx = ( tx * tex_sw( t ) + tex_sw( t ) * (double)( sx ) ) / tex_w( t );
+   tw = tw * tex_srw( t );
    if ( tw < 0 )
       tx -= tw;
-   ty = ( ty * t->sh + t->sh * ( t->sy - (double)sy - 1 ) ) / t->h;
-   th = th * t->srh;
+   ty = ( ty * tex_sh( t ) + tex_sh( t ) * ( tex_sy( t ) - (double)sy - 1 ) ) /
+        tex_h( t );
+   th = th * tex_srh( t );
    if ( th < 0 )
       ty -= th;
 
@@ -427,14 +426,16 @@ static int gfxL_renderTexH( lua_State *L )
    }
 
    /* Set the texture(s). */
-   glBindTexture( GL_TEXTURE_2D, t->texture );
+   glBindTexture( GL_TEXTURE_2D, tex_tex( t ) );
    glUniform1i( shader->MainTex, 0 );
    for ( int i = 0; i < array_size( shader->tex ); i++ ) {
-      LuaTexture_t *lt = &shader->tex[i];
+      const LuaTexture_t *lt = &shader->tex[i];
       glActiveTexture( lt->active );
       glBindTexture( GL_TEXTURE_2D, lt->texid );
       glUniform1i( lt->uniform, lt->value );
+      glBindSampler( lt->active - GL_TEXTURE0, tex_sampler( t ) );
    }
+   glBindSampler( 0, tex_sampler( t ) );
    glActiveTexture( GL_TEXTURE0 );
 
    /* Set shader uniforms. */
@@ -586,8 +587,10 @@ static int gfxL_renderLinesH( lua_State *L )
    const mat4     *H = luaL_checktransform( L, 1 );
    const glColour *c = luaL_optcolour( L, 2, &cWhite );
 
-   if ( vbo_lines == NULL )
+   if ( vbo_lines == NULL ) {
       vbo_lines = gl_vboCreateDynamic( 256 * sizeof( GLfloat ) * 2, NULL );
+      gl_vboLabel( vbo_lines, "Lua GFX Line VBO" );
+   }
 
    while ( !lua_isnoneornil( L, i ) ) {
       if ( n >= 256 ) {
@@ -833,7 +836,7 @@ static int gfxL_printRestoreLast( lua_State *L )
  *    @luatparam number y Y position to print at.
  *    @luatparam Colour col Colour to print text.
  *    @luatparam[opt] int max Maximum width to render up to.
- *    @luatparam[opt] boolean center Whether or not to center it.
+ *    @luatparam[opt] boolean centre Whether or not to centre it.
  * @luafunc printf
  */
 static int gfxL_printf( lua_State *L )
@@ -864,7 +867,7 @@ static int gfxL_printf( lua_State *L )
 }
 
 /**
- * @brief Prints text on the screen using a font with a transformation matirx.
+ * @brief Prints text on the screen using a font with a transformation matrix.
  *
  *    @luatparam Transform H transformation matrix to use.
  *    @luatparam font font Font to use.
@@ -900,7 +903,7 @@ static int gfxL_printH( lua_State *L )
  * Displays text in red at 50,50.
  * @usage gfx.print( true, _("Hello World!"), 50, 50, col, 100 ) -- Displays
  * text to a maximum of 100 pixels wide.
- * @usage gfx.print( true, str, 50, 50, col, 100, true ) -- Displays centered
+ * @usage gfx.print( true, str, 50, 50, col, 100, true ) -- Displays centred
  * text to a maximum of 100 pixels.
  *
  *    @luatparam boolean small Whether or not to use a small font.
@@ -909,7 +912,7 @@ static int gfxL_printH( lua_State *L )
  *    @luatparam number y Y position to print at.
  *    @luatparam Colour col Colour to print text.
  *    @luatparam[opt] int max Maximum width to render up to.
- *    @luatparam[opt] boolean center Whether or not to center it.
+ *    @luatparam[opt] boolean centre Whether or not to centre it.
  * @luafunc print
  */
 static int gfxL_print( lua_State *L )
@@ -985,10 +988,11 @@ static int gfxL_printText( lua_State *L )
  *
  * @usage gfx.setBlendMode( "alpha", "premultiplied" )
  *
- *    @luatparam string mode One of: "alpha", "replace", "screen", "add",
- * "subtract", "multiply", "lighten", or "darken".
+ *    @luatparam string mode One of: `"alpha"`, `"replace"`, `"screen"`,
+ * `"add"`,
+ * `"subtract"`, `"multiply"`, `"lighten"`, or `"darken"`.
  *    @luatparam[opt="alphamultiply"] string alphamode Override to
- * "premultiplied" when drawing canvases; see
+ * `premultiplied` when drawing canvases; see
  * https://love2d.org/wiki/BlendAlphaMode.
  * @luafunc setBlendMode
  */
@@ -1084,9 +1088,9 @@ static int gfxL_setBlendState( lua_State *L )
 }
 
 /**
- * @brief Sets the scissor clipping.
+ * @brief Sets the scissor clipping, with (0,0) at top-left.
  *
- * Calling setScissor with no parameters disables the clipping.
+ * Calling `setScissor` with no parameters disables the clipping.
  *
  *    @luatparam number x X position of the clipping rectangle.
  *    @luatparam number y Y position of the clipping rectangle.
@@ -1101,10 +1105,20 @@ static int gfxL_setScissor( lua_State *L )
       GLint   y = luaL_optinteger( L, 2, 0 );
       GLsizei w = luaL_optinteger( L, 3, 0 );
       GLsizei h = luaL_optinteger( L, 4, 0 );
-      gl_clipRect( x, y, w, h );
+
+      double rx, ry, rw, rh;
+      rx = x / gl_screen.mxscale;
+      ry = y / gl_screen.myscale;
+      rw = w / gl_screen.mxscale;
+      rh = h / gl_screen.myscale;
+      glScissor( rx, gl_screen.rh - rh - ry, rw, rh );
+      glEnable( GL_SCISSOR_TEST );
+
       render_needsReset();
-   } else
-      gl_unclipRect();
+   } else {
+      glDisable( GL_SCISSOR_TEST );
+      glScissor( 0, 0, gl_screen.rw, gl_screen.rh );
+   }
 
    if ( gl_checkErr() )
       NLUA_ERROR( L, _( "OpenGL Error!" ) );
@@ -1139,8 +1153,8 @@ static int gfxL_screenshot( lua_State *L )
    glBindFramebuffer( GL_READ_FRAMEBUFFER, 0 );
    glBindFramebuffer( GL_DRAW_FRAMEBUFFER, lc->fbo );
    /* We flip it over because that seems to be what love2d API wants. */
-   glBlitFramebuffer( 0, 0, gl_screen.rw, gl_screen.rh, 0, lc->tex->h,
-                      lc->tex->w, 0, GL_COLOR_BUFFER_BIT, GL_NEAREST );
+   glBlitFramebuffer( 0, 0, gl_screen.rw, gl_screen.rh, 0, tex_h( lc->tex ),
+                      tex_w( lc->tex ), 0, GL_COLOR_BUFFER_BIT, GL_NEAREST );
    glBindFramebuffer( GL_FRAMEBUFFER, 0 );
 
    /* Return new or old canvas. */
