@@ -16,6 +16,35 @@
 #include "nstring.h"
 #include "physics.h"
 
+/* Prototypes. */
+static int ss_statsMergeSingle( ShipStats *stats, const ShipStatList *list,
+                                int multiply );
+static int ss_statsMergeSingleScale( ShipStats *stats, const ShipStatList *list,
+                                     double scale, int multiply );
+
+/**
+ * @brief Represents relative ship statistics as a linked list.
+ *
+ * Doubles:
+ *  These values are relative so something like -0.15 would be -15%.
+ *
+ * Absolute and Integers:
+ *  These values are just absolute values.
+ *
+ * Booleans:
+ *  Can only be 1.
+ */
+typedef struct ShipStatList {
+   struct ShipStatList *next; /**< Next pointer. */
+
+   int           target; /**< Whether or not it affects the target. */
+   ShipStatsType type;   /**< Type of stat. */
+   union {
+      double d; /**< Floating point data. */
+      int    i; /**< Integer data. */
+   } d;         /**< Stat data. */
+} ShipStatList;
+
 /**
  * @brief The data type.
  */
@@ -33,7 +62,7 @@ typedef enum StatDataType_ {
  * Makes it much easier to work with stats at the cost of some minor
  * performance.
  */
-typedef struct ShipStatsLookup_ {
+typedef struct ShipStatsLookup {
    /* Explicitly set. */
    ShipStatsType type; /**< Type of the stat. */
    const char *
@@ -120,15 +149,18 @@ static const ShipStatsLookup ss_lookup[] = {
    DI_ELEM( SS_TYPE_D_LAND_DELAY, land_delay, N_( "Landing Time" ) ),
    DI_ELEM( SS_TYPE_D_CARGO_INERTIA, cargo_inertia, N_( "Cargo Inertia" ) ),
 
-   DI_ELEM( SS_TYPE_D_EW_HIDE, ew_hide, N_( "Detected Range" ) ),
+   DI_ELEM( SS_TYPE_D_EW_HIDE, ew_hide, N_( "Ship Detectability" ) ),
+   DI_ELEM( SS_TYPE_D_EW_DETECTED, ew_detected, N_( "Detected Range" ) ),
    DI_ELEM( SS_TYPE_D_EW_SIGNATURE, ew_signature, N_( "Signature Range" ) ),
    DI_ELEM( SS_TYPE_D_EW_STEALTH, ew_stealth, N_( "Stealth Range" ) ),
+   DI_ELEM( SS_TYPE_D_EW_STEALTH_MIN, ew_stealth_min,
+            N_( "Minimum Stealth Range" ) ),
    D__ELEM( SS_TYPE_D_EW_DETECT, ew_detect, N_( "Detection" ) ),
    D__ELEM( SS_TYPE_D_EW_TRACK, ew_track, N_( "Tracking" ) ),
    D__ELEM( SS_TYPE_D_EW_JUMPDETECT, ew_jump_detect, N_( "Jump Detection" ) ),
    DI_ELEM( SS_TYPE_D_EW_STEALTH_TIMER, ew_stealth_timer,
             N_( "Stealth Discovered Rate" ) ),
-   DI_ELEM( SS_TYPE_D_EW_SCANNED_TIME, ew_scanned_time, N_( "Scanned Speed" ) ),
+   D__ELEM( SS_TYPE_D_EW_SCANNED_TIME, ew_scanned_time, N_( "Scanned Time" ) ),
 
    D__ELEM( SS_TYPE_D_WEAPON_RANGE, weapon_range, N_( "Weapon Range" ) ),
    D__ELEM( SS_TYPE_D_WEAPON_DAMAGE, weapon_damage, N_( "Weapon Damage" ) ),
@@ -136,6 +168,8 @@ static const ShipStatsLookup ss_lookup[] = {
             N_( "Weapon Fire Rate" ) ),
    DI_ELEM( SS_TYPE_D_WEAPON_ENERGY, weapon_energy,
             N_( "Weapon Energy Usage" ) ),
+   D__ELEM( SS_TYPE_D_WEAPON_SPEED, weapon_speed,
+            N_( "Weapon Munition Speed" ) ),
 
    D__ELEM( SS_TYPE_D_LAUNCH_RATE, launch_rate, N_( "Fire Rate (Launcher)" ) ),
    D__ELEM( SS_TYPE_D_LAUNCH_RANGE, launch_range, N_( "Launch Range" ) ),
@@ -159,7 +193,6 @@ static const ShipStatsLookup ss_lookup[] = {
    D__ELEM( SS_TYPE_D_FBAY_RATE, fbay_rate, N_( "Fighter Bay Launch Rate" ) ),
    D__ELEM( SS_TYPE_D_FBAY_RELOAD, fbay_reload, N_( "Fighter Reload Rate" ) ),
 
-   DI_ELEM( SS_TYPE_D_FORWARD_HEAT, fwd_heat, N_( "Heat (Cannon)" ) ),
    D__ELEM( SS_TYPE_D_FORWARD_DAMAGE, fwd_damage, N_( "Damage (Cannon)" ) ),
    D__ELEM( SS_TYPE_D_FORWARD_FIRERATE, fwd_firerate,
             N_( "Fire Rate (Cannon)" ) ),
@@ -168,8 +201,9 @@ static const ShipStatsLookup ss_lookup[] = {
    D__ELEM( SS_TYPE_D_FORWARD_DAMAGE_AS_DISABLE, fwd_dam_as_dis,
             N_( "Damage as Disable (Cannon)" ) ),
    D__ELEM( SS_TYPE_D_FORWARD_RANGE, fwd_range, N_( "Weapon Range (Cannon)" ) ),
+   D__ELEM( SS_TYPE_D_FORWARD_SPEED, fwd_speed,
+            N_( "Munition Speed (Cannon)" ) ),
 
-   DI_ELEM( SS_TYPE_D_TURRET_HEAT, tur_heat, N_( "Heat (Turret)" ) ),
    D__ELEM( SS_TYPE_D_TURRET_DAMAGE, tur_damage, N_( "Damage (Turret)" ) ),
    D__ELEM( SS_TYPE_D_TURRET_TRACKING, tur_tracking,
             N_( "Tracking (Turret)" ) ),
@@ -180,9 +214,9 @@ static const ShipStatsLookup ss_lookup[] = {
    D__ELEM( SS_TYPE_D_TURRET_DAMAGE_AS_DISABLE, tur_dam_as_dis,
             N_( "Damage as Disable (Turret)" ) ),
    D__ELEM( SS_TYPE_D_TURRET_RANGE, tur_range, N_( "Weapon Range (Turret)" ) ),
+   D__ELEM( SS_TYPE_D_TURRET_SPEED, tur_speed,
+            N_( "Munition Speed (Turret)" ) ),
 
-   D__ELEM( SS_TYPE_D_HEAT_DISSIPATION, heat_dissipation,
-            N_( "Heat Dissipation" ) ),
    D__ELEM( SS_TYPE_D_STRESS_DISSIPATION, stress_dissipation,
             N_( "Stress Dissipation" ) ),
    D__ELEM( SS_TYPE_D_CREW, crew_mod, N_( "Crew" ) ),
@@ -216,9 +250,11 @@ static const ShipStatsLookup ss_lookup[] = {
             _UNIT_POWER ),
    AI_ELEM( SS_TYPE_A_ARMOUR_REGEN_MALUS, armour_regen_malus,
             N_( "Armour Damage" ), _UNIT_POWER ),
-   A__ELEM( SS_TYPE_A_DAMAGE, damage, N_( "Damage" ), _UNIT_POWER ),
-   A__ELEM( SS_TYPE_A_DISABLE, disable, N_( "Disable" ), _UNIT_POWER ),
+   AI_ELEM( SS_TYPE_A_DAMAGE, damage, N_( "Damage" ), _UNIT_POWER ),
+   AI_ELEM( SS_TYPE_A_DISABLE, disable, N_( "Disable" ), _UNIT_POWER ),
 
+   AI_ELEM( SS_TYPE_A_MASS, mass, N_( "Ship Mass" ), _UNIT_MASS ),
+   A__ELEM( SS_TYPE_A_CPU, cpu, N_( "CPU Usage" ), _UNIT_CPU ),
    A__ELEM( SS_TYPE_A_CPU_MAX, cpu_max, N_( "CPU Capacity" ), _UNIT_CPU ),
    A__ELEM( SS_TYPE_A_ENGINE_LIMIT, engine_limit, N_( "Engine Mass Limit" ),
             _UNIT_MASS ),
@@ -244,6 +280,7 @@ static const ShipStatsLookup ss_lookup[] = {
    B__ELEM( SS_TYPE_B_INSTANT_JUMP, misc_instant_jump, N_( "Instant Jump" ) ),
    B__ELEM( SS_TYPE_B_REVERSE_THRUST, misc_reverse_thrust,
             N_( "Reverse Thrusters" ) ),
+   B__ELEM( SS_TYPE_B_INVINCIBLE, invincible, N_( "Temporary invincibility" ) ),
 
    /* Sentinel. */
    N__ELEM( SS_TYPE_SENTINEL ) };
@@ -344,13 +381,7 @@ ShipStatList *ss_statsSetList( ShipStatList *head, ShipStatsType type,
    return newhead;
 }
 
-/**
- * @brief Creates a shipstat list element from an xml node.
- *
- *    @param node Node to create element from.
- *    @return List element created from node.
- */
-ShipStatList *ss_listFromXML( xmlNodePtr node )
+ShipStatList *ss_listFromXMLSingle( ShipStatList *head, xmlNodePtr node )
 {
    const ShipStatsLookup *sl;
    ShipStatList          *ll;
@@ -358,12 +389,14 @@ ShipStatList *ss_listFromXML( xmlNodePtr node )
 
    /* Try to get type. */
    type = ss_typeFromName( (char *)node->name );
-   if ( type == SS_TYPE_NIL )
-      return NULL;
+   if ( type == SS_TYPE_NIL ) {
+      WARN( "Ship Stat List has unknown node '%s'", node->name );
+      return head;
+   }
 
    /* Allocate. */
    ll         = malloc( sizeof( ShipStatList ) );
-   ll->next   = NULL;
+   ll->next   = head;
    ll->target = 0;
    ll->type   = type;
 
@@ -395,10 +428,27 @@ ShipStatList *ss_listFromXML( xmlNodePtr node )
 }
 
 /**
- * @brief Creatse a shipstat list element from an xml node.
+ * @brief Creates a shipstat list element from an xml node.
+ *
+ *    @param node Node to create element from.
+ *    @return List element created from node.
+ */
+ShipStatList *ss_listFromXML( xmlNodePtr node )
+{
+   ShipStatList *head = NULL;
+   xmlNodePtr    cur  = node->children;
+   do {
+      xml_onlyNodes( cur );
+      head = ss_listFromXMLSingle( head, cur );
+   } while ( xml_nextNode( cur ) );
+   return head;
+}
+
+/**
+ * @brief Create a shipstat list element from an xml node.
  *
  *    @param writer Writer to use to write the XML data.
- *    @param ll ShipStats to save.
+ *    @param ll The `ShipStats` to save.
  *    @return 0 on success.
  */
 int ss_listToXML( xmlTextWriterPtr writer, const ShipStatList *ll )
@@ -529,8 +579,9 @@ int ss_statsInit( ShipStats *stats )
  *
  *    @param dest Destination ship stats.
  *    @param src Source to be merged with destination.
+ *    @param multiply Whether or not to use multiplication for merging.
  */
-int ss_statsMerge( ShipStats *dest, const ShipStats *src )
+int ss_statsMerge( ShipStats *dest, const ShipStats *src, int multiply )
 {
    int          *destint;
    const int    *srcint;
@@ -550,22 +601,25 @@ int ss_statsMerge( ShipStats *dest, const ShipStats *src )
 
       switch ( sl->data ) {
       case SS_DATA_TYPE_DOUBLE:
-         destdbl  = (double *)(void *)&destptr[sl->offset];
-         srcdbl   = (const double *)(const void *)&srcptr[sl->offset];
-         *destdbl = ( *destdbl ) * ( *srcdbl );
+         destdbl = (double *)(void *)&destptr[sl->offset];
+         srcdbl  = (const double *)(const void *)&srcptr[sl->offset];
+         if ( multiply )
+            *destdbl *= *srcdbl;
+         else
+            ss_adjustDoubleStat( destdbl, *srcdbl, sl->inverted );
          break;
 
       case SS_DATA_TYPE_DOUBLE_ABSOLUTE:
       case SS_DATA_TYPE_DOUBLE_ABSOLUTE_PERCENT:
-         destdbl  = (double *)(void *)&destptr[sl->offset];
-         srcdbl   = (const double *)(const void *)&srcptr[sl->offset];
-         *destdbl = ( *destdbl ) + ( *srcdbl );
+         destdbl = (double *)(void *)&destptr[sl->offset];
+         srcdbl  = (const double *)(const void *)&srcptr[sl->offset];
+         *destdbl += *srcdbl;
          break;
 
       case SS_DATA_TYPE_INTEGER:
-         destint  = (int *)&destptr[sl->offset];
-         srcint   = (const int *)&srcptr[sl->offset];
-         *destint = ( *destint ) + ( *srcint );
+         destint = (int *)&destptr[sl->offset];
+         srcint  = (const int *)&srcptr[sl->offset];
+         *destint += *srcint;
          break;
 
       case SS_DATA_TYPE_BOOLEAN:
@@ -584,11 +638,13 @@ int ss_statsMerge( ShipStats *dest, const ShipStats *src )
  *
  *    @param stats Stat structure to modify.
  *    @param list Single element to apply.
+ *    @param multiply Whether or not to use multiplication for merging.
  *    @return 0 on success.
  */
-int ss_statsMergeSingle( ShipStats *stats, const ShipStatList *list )
+static int ss_statsMergeSingle( ShipStats *stats, const ShipStatList *list,
+                                int multiply )
 {
-   return ss_statsMergeSingleScale( stats, list, 1 );
+   return ss_statsMergeSingleScale( stats, list, 1., multiply );
 }
 
 /**
@@ -615,10 +671,11 @@ static void ss_adjustDoubleStat( double *statptr, double adjustment,
  *    @param stats Stat structure to modify.
  *    @param list Single element to apply.
  *    @param scale Scaling factor.
+ *    @param multiply Whether or not to use multiplication for merging.
  *    @return 0 on success.
  */
-int ss_statsMergeSingleScale( ShipStats *stats, const ShipStatList *list,
-                              double scale )
+static int ss_statsMergeSingleScale( ShipStats *stats, const ShipStatList *list,
+                                     double scale, int multiply )
 {
    char                  *ptr;
    char                  *fieldptr;
@@ -631,8 +688,12 @@ int ss_statsMergeSingleScale( ShipStats *stats, const ShipStatList *list,
    case SS_DATA_TYPE_DOUBLE:
       fieldptr = &ptr[sl->offset];
       memcpy( &dbl, &fieldptr, sizeof( double * ) );
-      ss_adjustDoubleStat( dbl, list->d.d * scale, sl->inverted );
+      if ( multiply )
+         *dbl *= 1. + list->d.d * scale;
+      else
+         ss_adjustDoubleStat( dbl, list->d.d * scale, sl->inverted );
       break;
+
    case SS_DATA_TYPE_DOUBLE_ABSOLUTE:
    case SS_DATA_TYPE_DOUBLE_ABSOLUTE_PERCENT:
       fieldptr = &ptr[sl->offset];
@@ -661,15 +722,17 @@ int ss_statsMergeSingleScale( ShipStats *stats, const ShipStatList *list,
  *
  *    @param stats Stats to update.
  *    @param list List to update from.
+ *    @param multiply Whether or not to use multiplication for merging.
  *    @return 0 on success.
  */
-int ss_statsMergeFromList( ShipStats *stats, const ShipStatList *list )
+int ss_statsMergeFromList( ShipStats *stats, const ShipStatList *list,
+                           int multiply )
 {
    if ( list == NULL )
       return 0;
    int ret = 0;
    for ( const ShipStatList *ll = list; ll != NULL; ll = ll->next )
-      ret |= ss_statsMergeSingle( stats, ll );
+      ret |= ss_statsMergeSingle( stats, ll, multiply );
    return ret;
 }
 
@@ -679,16 +742,17 @@ int ss_statsMergeFromList( ShipStats *stats, const ShipStatList *list )
  *    @param stats Stats to update.
  *    @param list List to update from.
  *    @param scale Scaling factor.
+ *    @param multiply Whether or not to use multiplication for merging.
  *    @return 0 on success.
  */
 int ss_statsMergeFromListScale( ShipStats *stats, const ShipStatList *list,
-                                double scale )
+                                double scale, int multiply )
 {
    if ( list == NULL )
       return 0;
    int ret = 0;
    for ( const ShipStatList *ll = list; ll != NULL; ll = ll->next )
-      ret |= ss_statsMergeSingleScale( stats, ll, scale );
+      ret |= ss_statsMergeSingleScale( stats, ll, scale, multiply );
    return ret;
 }
 
@@ -724,15 +788,29 @@ size_t ss_offsetFromType( ShipStatsType type )
  */
 ShipStatsType ss_typeFromName( const char *name )
 {
-   for ( int i = 0; i < SS_TYPE_SENTINEL; i++ )
-      if ( ( ss_lookup[i].name != NULL ) &&
-           ( strcmp( name, ss_lookup[i].name ) == 0 ) )
-         return ss_lookup[i].type;
+   if ( name == NULL )
+      return SS_TYPE_NIL;
+   for ( int i = 0; i < SS_TYPE_SENTINEL; i++ ) {
+      const ShipStatsLookup *lu = &ss_lookup[i];
+      if ( ( lu->name != NULL ) && ( strcmp( name, lu->name ) == 0 ) )
+         return lu->type;
+   }
 
    WARN( _( "ss_typeFromName: No ship stat matching '%s'" ), name );
    return SS_TYPE_NIL;
 }
 
+/**
+ * @brief Small hack to make our life easier in Rust.
+ */
+double ss_offsetStat( const ShipStats *s, size_t offset )
+{
+   double      out;
+   const char *ptr = (const char *)s;
+   memcpy( &out, &ptr[offset], sizeof( double ) );
+   return out;
+}
+
 /**
  * @brief Some colour coding for ship stats doubles.
  */
@@ -940,6 +1018,22 @@ void ss_free( ShipStatList *ll )
    }
 }
 
+/**
+ * @brief Duplicates a ship stat list.
+ */
+ShipStatList *ss_dupList( const ShipStatList *ll )
+{
+   ShipStatList *head = NULL;
+   while ( ll != NULL ) {
+      ShipStatList *ln = calloc( 1, sizeof( ShipStatList ) );
+      *ln              = *ll;
+      ln->next         = head;
+      head             = ln;
+      ll               = ll->next;
+   }
+   return head;
+}
+
 /**
  * @brief Sets a ship stat by name.
  */
@@ -1190,3 +1284,31 @@ int ss_statsGetLuaTableList( lua_State *L, const ShipStatList *list,
    }
    return 0;
 }
+
+/**
+ * @brief Exports the ship stats to Lua.
+ */
+void ss_exportLua( lua_State *L )
+{
+   lua_newtable( L );
+   for ( ShipStatsType i = 0; i <= SS_TYPE_SENTINEL; i++ ) {
+      const ShipStatsLookup *ss = &ss_lookup[i];
+      lua_newtable( L );
+
+      lua_pushstring( L, ss->name );
+      lua_setfield( L, -2, "name" );
+
+      lua_pushstring( L, ss->display );
+      lua_setfield( L, -2, "display" );
+
+      if ( ss->unit != NULL ) {
+         lua_pushstring( L, ss->unit );
+         lua_setfield( L, -2, "unit" );
+      }
+
+      lua_pushboolean( L, ss->inverted );
+      lua_setfield( L, -2, "inverted" );
+
+      lua_rawseti( L, -2, i + 1 );
+   }
+}
