@@ -5,10 +5,6 @@
 
 #include "opengl_tex.h"
 
-/* Load/exit. */
-int  sp_load( void );
-void sp_cleanup( void );
-
 /* Stuff. */
 unsigned int     sp_get( const char *name );
 const char      *sp_display( unsigned int sp );
@@ -18,3 +14,4 @@ int              sp_required( unsigned int spid );
 int              sp_exclusive( unsigned int spid );
 int              sp_locked( unsigned int spid );
 const glTexture *sp_icon( unsigned int spid );
+const char     **sp_tags( unsigned int spid );
